@@ -19,3 +19,7 @@ class AddTemplateDriveView(generic.ObjectEditView):
 class AddTemplatePartitionView(generic.ObjectEditView):
     queryset = LinuxDevice.objects.all()
     form = PartitionTemplateForm
+
+
+class SyncTemplateToVMView():
+    print("Hello")
